@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
-our $DATE = '2017-01-15'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $DATE = '2017-02-11'; # DATE
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 use strict;
@@ -800,7 +800,7 @@ sub list_modules {
                      <td><a[^>]+>(.+?)</a></td>\s*
                      <td><a[^>]+>(.+?)</a></td>\s*
                      <td>(.+?)</td>\s*
-                     <td>(.+?)</td>\s*
+                     <td>(.*?)</td>\s*
                      </tr>!gsx) {
         my $rec = {module=>$1, userid=>$2, type=>$3, owner=>$4};
 
@@ -851,7 +851,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.35 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-01-15.
+This document describes version 0.36 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-02-11.
 
 =head1 SYNOPSIS
 
@@ -863,7 +863,11 @@ There is also a CLI script L<pause> distributed separately in L<App::pause>.
 =head1 FUNCTIONS
 
 
-=head2 delete_files(%args) -> [status, msg, result, meta]
+=head2 delete_files
+
+Usage:
+
+ delete_files(%args) -> [status, msg, result, meta]
 
 Delete files.
 
@@ -934,7 +938,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 delete_old_releases(%args) -> [status, msg, result, meta]
+=head2 delete_old_releases
+
+Usage:
+
+ delete_old_releases(%args) -> [status, msg, result, meta]
 
 Delete older versions of distributions.
 
@@ -1016,7 +1024,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 list_dists(%args) -> [status, msg, result, meta]
+=head2 list_dists
+
+Usage:
+
+ list_dists(%args) -> [status, msg, result, meta]
 
 List distributions.
 
@@ -1082,7 +1094,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 list_files(%args) -> [status, msg, result, meta]
+=head2 list_files
+
+Usage:
+
+ list_files(%args) -> [status, msg, result, meta]
 
 List files.
 
@@ -1140,7 +1156,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 list_modules(%args) -> [status, msg, result, meta]
+=head2 list_modules
+
+Usage:
+
+ list_modules(%args) -> [status, msg, result, meta]
 
 List modules (permissions).
 
@@ -1198,7 +1218,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 reindex_files(%args) -> [status, msg, result, meta]
+=head2 reindex_files
+
+Usage:
+
+ reindex_files(%args) -> [status, msg, result, meta]
 
 Force reindexing.
 
@@ -1261,7 +1285,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 undelete_files(%args) -> [status, msg, result, meta]
+=head2 undelete_files
+
+Usage:
+
+ undelete_files(%args) -> [status, msg, result, meta]
 
 Undelete files.
 
@@ -1328,7 +1356,11 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 upload_files(%args) -> [status, msg, result, meta]
+=head2 upload_files
+
+Usage:
+
+ upload_files(%args) -> [status, msg, result, meta]
 
 Upload file(s).
 
@@ -1436,7 +1468,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
